---
title: <span class="badge object-type-scalar"></span> IsraeliNewShekels
---
# <span class="badge object-type-scalar"></span> IsraeliNewShekels

Currency: Israeli New Shekels (₪)

## Definition

```python
# Currency: Israeli New Shekels (₪)
IsraeliNewShekels: typing.Literal["currencyILS"] = "currencyILS"
```
